Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1507)

Unified Diff: src/gpu/GrPipelineBuilder.h

Issue 1161273005: Update XPF invariant info to not account for conflation (Closed) Base URL: https://skia.googlesource.com/skia.git@upload_reenablebea
Patch Set: rebase Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrPaint.cpp ('k') | src/gpu/GrPipelineBuilder.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrPipelineBuilder.h
diff --git a/src/gpu/GrPipelineBuilder.h b/src/gpu/GrPipelineBuilder.h
index 09b4f91e7304760e8b386c579bf8af1aeeb25ba7..dbbf98a815a8dedfd418743b61814a3622baa101 100644
--- a/src/gpu/GrPipelineBuilder.h
+++ b/src/gpu/GrPipelineBuilder.h
@@ -139,10 +139,12 @@ public:
////
/**
- * This function returns true if the render target destination pixel values will be read for
- * blending during draw.
+ * Returns true if this pipeline's color output will be affected by the existing render target
+ * destination pixel values (meaning we need to be careful with overlapping draws). Note that we
+ * can conflate coverage and color, so the destination color may still bleed into pixels that
+ * have partial coverage, even if this function returns false.
*/
- bool willBlendWithDst(const GrPrimitiveProcessor*) const;
+ bool willColorBlendWithDst(const GrPrimitiveProcessor*) const;
/**
* Installs a GrXPFactory. This object controls how src color, fractional pixel coverage,
@@ -387,7 +389,7 @@ private:
//
// canUseFracCoveragePrimProc() - Called in regular skia draw, caches results but only for a
// specific color and coverage. May be called multiple times
// willBlendWithDst() - only called by Nvpr, does not cache results
// GrOptDrawState constructor - never caches results
/**
« no previous file with comments | « src/gpu/GrPaint.cpp ('k') | src/gpu/GrPipelineBuilder.cpp » ('j') | no next file with comments »
@@ -387,7 +389,7 @@ private:
// canUseFracCoveragePrimProc() - Called in regular skia draw, caches results but only for a
// specific color and coverage. May be called multiple times
- // willBlendWithDst() - only called by Nvpr, does not cache results
+ // willColorBlendWithDst() - only called by Nvpr, does not cache results
// GrOptDrawState constructor - never caches results
/**

Powered by Google App Engine
This is Rietveld 408576698